@@ -669,11 +669,11 @@ class MyWhatify:
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
             path = os.path.join(os.path.dirname(__file__))
             list_dir = os.listdir(path)
-            with allure.step("looking at the dir name list: " + str(list_dir)):
+            with allure.step("looking inside path: " + str(path) + " the dir name list: " + str(list_dir)):
                 logging.info("looking at the dir name list: " + str(list_dir))
                 path = os.path.join(os.path.dirname(__file__), 'data_source')
                 list_dir = os.listdir(path)
-                with allure.step("looking inside the data_source in dir name list: " + str(list_dir)):
+                with allure.step("looking inside path " + str(path) + " the data_source in dir name list: " + str(list_dir)):
                     logging.info("looking inside the data_source in dir name list: " + str(list_dir))
 
             # script_dir = os.getcwd()
